@@ -1,7 +1,7 @@
 /*
- *  $Id: CgiInput.cpp,v 1.2 2002/03/03 17:39:52 sbooth Exp $
+ *  $Id: CgiInput.cpp,v 1.4 2003/07/13 14:20:35 sbooth Exp $
  *
- *  Copyright (C) 1996 - 2002 Stephen F. Booth
+ *  Copyright (C) 1996 - 2003 Stephen F. Booth
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -29,22 +29,22 @@
 
 // ========== Destructor
 
-CGICCNS CgiInput::~CgiInput()
+cgicc::CgiInput::~CgiInput()
 {}
 
 // ========== Members
 
 size_t 
-CGICCNS CgiInput::read(char *data, 
+cgicc::CgiInput::read(char *data, 
 		       size_t length)
 {
-  STDNS cin.read(data, length);
-  return STDNS cin.gcount();
+  std::cin.read(data, length);
+  return std::cin.gcount();
 }
 
-STDNS string
-CGICCNS CgiInput::getenv(const char *varName)
+std::string
+cgicc::CgiInput::getenv(const char *varName)
 {
-  char *var = STDNS getenv(varName);
-  return (var == 0) ? "" : var;
+  char *var = std::getenv(varName);
+  return (var == 0) ? std::string("") : var;
 }
