@@ -1,7 +1,7 @@
 /*
- *  $Id: HTTPPlainHeader.cpp,v 1.2 2002/03/06 02:49:55 sbooth Exp $
+ *  $Id: HTTPPlainHeader.cpp,v 1.4 2003/07/13 14:20:35 sbooth Exp $
  *
- *  Copyright (C) 1996 - 2002 Stephen F. Booth
+ *  Copyright (C) 1996 - 2003 Stephen F. Booth
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,9 @@
 // ============================================================
 // Class HTTPPlainHeader
 // ============================================================
-CGICCNS HTTPPlainHeader::HTTPPlainHeader()
+cgicc::HTTPPlainHeader::HTTPPlainHeader()
   : HTTPContentHeader("text/plain")
 {}
 
-CGICCNS HTTPPlainHeader::~HTTPPlainHeader()
+cgicc::HTTPPlainHeader::~HTTPPlainHeader()
 {}
