@@ -1,7 +1,7 @@
 /*
- *  $Id: dns.cpp,v 1.13 2000/10/15 15:59:20 sbooth Exp $
+ *  $Id: dns.cpp,v 1.19 2003/07/13 14:22:57 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
+ *  Copyright (C) 1996 - 2003 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,6 +18,14 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/*! \file dns.cpp
+ * \brief A WWW to DNS gateway
+ *
+ * A sample CGI application using the GNU %cgicc library.  This script 
+ * allows users to lookup the IP address corresponding to a hostname, 
+ * or vice-versa.
+ */
+
 #include <cstdlib>
 #include <new>
 #include <vector>
@@ -25,8 +33,9 @@
 #include <iostream>
 
 #include "cgicc/CgiDefs.h"
-#include "cgicc/HTMLClasses.h"
 #include "cgicc/Cgicc.h"
+#include "cgicc/HTTPHTMLHeader.h"
+#include "cgicc/HTMLClasses.h"
 
 #if HAVE_UNAME
 #  include <sys/utsname.h>
@@ -49,17 +58,11 @@
 // To use logging, the variable gLogFile MUST be defined, and it _must_
 // be an ofstream
 #if DEBUG
-  STDNS ofstream gLogFile( "/change_this_path/cgicc.log", STDNS ios::app );
+  std::ofstream gLogFile( "/change_this_path/cgicc.log", std::ios::app );
 #endif
 
-#if CGICC_USE_NAMESPACES
-  using namespace std;
-  using namespace cgicc;
-#else
-#  define div div_
-#  define link link_
-#  define select select_
-#endif
+using namespace std;
+using namespace cgicc;
 
 // DNS gateway cgi
 int
@@ -76,7 +79,7 @@ main(int /*argc*/,
     Cgicc cgi;
     
     cout << HTTPHTMLHeader() << HTMLDoctype(HTMLDoctype::eStrict) << endl;
-    cout << html().set("lang","EN").set("dir","LTR") << endl;
+    cout << html().set("lang","en").set("dir","ltr") << endl;
     
     // Set up the page; I will put in lfs to ease reading of the
     // produced HTML. These are optional, and except in <PRE>
@@ -85,21 +88,19 @@ main(int /*argc*/,
 
     // Output the style sheet portion of the header
     cout << style() << comment() << endl;
-    cout << "BODY { color: black; background-color: white; }" << endl;
-    cout << "HR.half { width: 60%; align: center; }" << endl;
-    cout << "SPAN.red, STRONG.red { color: red; }" << endl;
-    cout << "DIV.smaller { font-size: small; }" << endl;
-    cout << "DIV.dns { border: solid thin; margin: 1em 0; "
-	 << "background: #DDD; text-align: center; }" << endl;
-    cout << "SPAN.blue { color: blue; }" << endl;
-    cout << "COL.title { color: white; background-color: black; ";
+    cout << "body { color: black; background-color: white; }" << endl;
+    cout << "hr.half { width: 60%; align: center; }" << endl;
+    cout << "span.red, strong.red { color: red; }" << endl;
+    cout << "div.smaller { font-size: small; }" << endl;
+    cout << "div.dns { border: solid thin; margin: 1em 0; "
+	 << "background: #ddd; text-align: center; }" << endl;
+    cout << "span.blue { color: blue; }" << endl;
+    cout << "col.title { color: white; background-color: black; ";
     cout << "font-weight: bold; text-align: center; }" << endl;
-    cout << "COL.data { background-color: #DDD; text-align: left; }" << endl;
+    cout << "col.data { background-color: #ddd; text-align: left; }" << endl;
     cout << comment() << style() << endl;
 
     cout << title("DNS Gateway") << endl;
-    cout << meta().set("name", "author")
-		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
     
     cout << h1() << "GNU cgi" << span("cc").set("class","red")
@@ -116,18 +117,18 @@ main(int /*argc*/,
       char **p;
       
       if((int)(addr = inet_addr((**ip).c_str())) == -1) {
-	cout << CGICCNS div().set("class", "dns") << endl
+	cout << cgicc::div().set("class", "dns") << endl
 	     << strong(span("ERROR").set("class","red"))
 	     << " - IP address must be of the form x.x.x.x"
-	     << endl << CGICCNS div() << endl;
+	     << endl << cgicc::div() << endl;
       }
       else {
 	hp = gethostbyaddr((char*)&addr, sizeof (addr), AF_INET);
 	if(hp == NULL) {
-	  cout << CGICCNS div().set("class", "dns") << endl
+	  cout << cgicc::div().set("class", "dns") << endl
 	       << strong(span("ERROR").set("class","red")) 
 	       << " - Host information for " << em((**ip)) << " not found."
-	       << endl << CGICCNS div() << endl;
+	       << endl << cgicc::div() << endl;
 	}
 	else {
 	  for(p = hp->h_addr_list; *p != 0; p++) {
@@ -136,12 +137,12 @@ main(int /*argc*/,
 	    
 	    (void) memcpy(&in.s_addr, *p, sizeof(in.s_addr));
 	    
-	    cout << CGICCNS div().set("class", "dns") << endl
+	    cout << cgicc::div().set("class", "dns") << endl
 		 << span(inet_ntoa(in)).set("class","blue") 
 		 << " - " << ' ' << hp->h_name;
 	    //for(q = hp->h_aliases; *q != 0; q++)
 	    //	    cout << *q << ' ';
-	    cout << endl << CGICCNS div() << endl;
+	    cout << endl << cgicc::div() << endl;
 	  }
 	}
       }
@@ -156,10 +157,10 @@ main(int /*argc*/,
       
       hp = gethostbyname((**name).c_str());
       if(hp == NULL) {
-	cout << CGICCNS div().set("class", "dns") << endl
+	cout << cgicc::div().set("class", "dns") << endl
 	     << strong(span("ERROR").set("class","red"))
 	     << " - Host information for " << em(**name) << " not found."
-	     << endl << CGICCNS div() << endl;
+	     << endl << cgicc::div() << endl;
       }
       else {
 	for(p = hp->h_addr_list; *p != 0; p++) {
@@ -168,12 +169,12 @@ main(int /*argc*/,
 	  
 	  (void) memcpy(&in.s_addr, *p, sizeof(in.s_addr));
 	  
-	  cout << CGICCNS div().set("class", "dns") << endl
+	  cout << cgicc::div().set("class", "dns") << endl
 	       << inet_ntoa(in) << " - " << ' ' 
 	       << span(hp->h_name).set("class","blue");
 	  //	for(q = hp->h_aliases; *q != 0; q++)
 	  //	  cout << *q << ' ';
-	  cout << endl << CGICCNS div() << endl;
+	  cout << endl << cgicc::div() << endl;
 	}
       }
     }
@@ -193,7 +194,7 @@ main(int /*argc*/,
 		 .set("span","1") << endl;
     cout << colgroup() << endl;
     
-    cout << "<FORM METHOD=\"POST\" ACTION=\"http://"
+    cout << "<form method=\"post\" action=\"http://"
 	 << cgi.getEnvironment().getServerName();
     if(cgi.getEnvironment().getServerPort() != 80)
       cout << ":" << cgi.getEnvironment().getServerPort();
@@ -201,14 +202,14 @@ main(int /*argc*/,
     
     cout << tr() << endl;
     cout << td(strong("IP Address: ")) << endl;
-    cout << td() << "<INPUT TYPE=\"TEXT\" NAME=\"ip\"";
+    cout << td() << "<input type=\"text\" name=\"ip\"";
     if(ip != (*cgi).end())
-      cout << " VALUE=\"" << **ip << "\">";
+      cout << " value=\"" << **ip << "\">";
     else
       cout << ">";
-    cout << td() << tr() << "</FORM>" << endl;
+    cout << td() << tr() << "</form>" << endl;
     
-    cout << "<FORM METHOD=\"POST\" ACTION=\"http://"
+    cout << "<form method=\"post\" action=\"http://"
 	 << cgi.getEnvironment().getServerName();
     if(cgi.getEnvironment().getServerPort() != 80)
       cout << ":" << cgi.getEnvironment().getServerPort();
@@ -216,22 +217,19 @@ main(int /*argc*/,
     
     cout << tr() << endl;
     cout << td(strong("Hostname: ")) << endl;
-    cout << td() << "<INPUT TYPE=\"TEXT\" NAME=\"hostname\"";
+    cout << td() << "<input type=\"text\" name=\"hostname\"";
     if(name != (*cgi).end())
-      cout << " VALUE=\"" << **name << "\">";
+      cout << " value=\"" << **name << "\">";
     else
       cout << ">";
     cout << td() << tr() << endl;
-    cout << "</FORM>" << table() << p() << endl;
+    cout << "</form>" << table() << p() << endl;
     
     // Now print cout a footer with some fun info
     cout << hr(set("class","half")) << endl;
-    cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
+    cout << cgicc::div().set("align","center").set("class","smaller") << endl;
     cout << "GNU cgi" << span("cc").set("class","red") << " v"
-	 << cgi.getVersion();
-    cout << " by " << a("Stephen F. Booth")
-			.set("href", "http://home.earthlink.net/~sfbooth/") 
-	 << br() << endl;
+	 << cgi.getVersion() << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime() 
 	 << " on " << cgi.getCompileDate() << br() << endl;
     
@@ -260,13 +258,13 @@ main(int /*argc*/,
 #endif
     
     // End of document
-    cout << CGICCNS div() << endl;
+    cout << cgicc::div() << endl;
     cout << body() << html() << endl;
 
     return EXIT_SUCCESS;
   }
 
-  catch(const STDNS exception& e) {
+  catch(const std::exception& e) {
     return EXIT_FAILURE;
   }
 }
